@@ -17,8 +17,9 @@ class Forex:
 
     def performance(self, change='percent'):
         """Get forex performance table.
+
         Args:
-            change (str): choose a option of change(percent, PIPS)
+            change (str): choose an option of change(percent, PIPS)
 
         Returns:
             df(pandas.DataFrame): forex performance table
@@ -34,14 +35,19 @@ class Forex:
         df = scrapFunction(url)
         return df
 
-    def chart(self, forex, timeframe='D'):
+    def chart(self, forex, timeframe='D', urlonly=False):
         """Get forex chart.
+
         Args:
             forex (str): foreign exchange name
             timeframe (str): choice of timeframe(5M, H, D, W, M)
+            urlonly (bool): choice of downloading charts, default: downloading chart
+        Returns:
+            charturl(str): url for the chart
         """
         if forex == '':
             return None
 
         url = 'https://finviz.com/forex_charts.ashx?t=ALL&tf='
-        imageScrapFunction(url, forex, timeframe)
\ No newline at end of file
+        charturl = imageScrapFunction(url, forex, timeframe, urlonly)
+        return charturl
\ No newline at end of file
